# django-genericimports

**STATUS**: beta2

**NOTE**: This application is still not ready for production. Use it at your own risk.

Django application to import data regardless of data/field/thirdparty types or headers. This importer is focused on functionality, completeness, data cleanliness and reporting, not on speed itself.

Check the documentation at: http://django-genericimports.readthedocs.org/en/latest/

# License

This application is licensed in BSD 2-Clause license. This application was developed while at work on Havas Worldwide London, so part of the kudos goes to them as well.

# Authors

- Oscar Carballal Prego <oscar.carballal@gmail.com>
- Max Barry <max.barry@havasww.com>
